slabbe: Code for discrete dynamical systems, combinatorics, digital geometry
============================================================================

Description
-----------

This SageMath package contains various modules by Sébastien Labbé
for experimentation with

- discrete dynamical systems
- combinatorics
- digital geometry
- visualization
- miscellaneous development tools

License
-------

GPLv2+

Upstream Contact
----------------

- https://pypi.org/project/slabbe/
- https://github.com/passagemath/passagemath-pkg-slabbe
